@@ -33,13 +33,15 @@ fn run() -> io::Result<()> {
     } else {
         let stdin = io::stdin();
         let mut buf = vec![];
+
         while let Some(size) = stdin.lock().read_until(b'\n', &mut buf).ok() {
             if size == 0 {
                 break;
             }
 
             let path_str = String::from_utf8_lossy(&buf[..(buf.len() - 1)]);
-
+            #[cfg(windows)]
+            let path_str = path_str.trim_end_matches('\r');
             print_path(&mut stdout, &ls_colors, path_str.as_ref())?;
 
             buf.clear();
