@@ -7,6 +7,9 @@ use std::collections::VecDeque;
 #[cfg(ansi_term)]
 use ansi_term;
 
+#[cfg(crossterm)]
+use crossterm;
+
 /// A `Color` can be one of the pre-defined ANSI colors (`Red`, `Green`, ..),
 /// a 8-bit ANSI color (`Fixed(u8)`) or a 24-bit color (`RGB(u8, u8, u8)`).
 #[derive(Debug, Clone, PartialEq)]
@@ -40,6 +43,27 @@ impl Color {
             Color::White => ansi_term::Color::White,
         }
     }
+
+    /// Convert to a `crossterm::style::Color` (if the `crossterm` feature is enabled).
+    #[cfg(feature = "crossterm")]
+    pub fn to_crossterm_color(&self) -> crossterm::style::Color {
+        match self {
+            Color::RGB(r, g, b) => crossterm::style::Color::Rgb {
+                r: *r,
+                g: *g,
+                b: *b,
+            },
+            Color::Fixed(n) => crossterm::style::Color::AnsiValue(*n),
+            Color::Black => crossterm::style::Color::Black,
+            Color::Red => crossterm::style::Color::Red,
+            Color::Green => crossterm::style::Color::Green,
+            Color::Yellow => crossterm::style::Color::Yellow,
+            Color::Blue => crossterm::style::Color::Blue,
+            Color::Magenta => crossterm::style::Color::Magenta,
+            Color::Cyan => crossterm::style::Color::Cyan,
+            Color::White => crossterm::style::Color::White,
+        }
+    }
 }
 
 /// Font-style attributes.
@@ -119,6 +143,40 @@ impl FontStyle {
             ..Default::default()
         }
     }
+
+    /// Convert to `crossterm::style::Attributes` (if the `crossterm` feature is enabled).
+    #[cfg(feature = "crossterm")]
+    pub fn to_crossterm_attributes(&self) -> crossterm::style::Attributes {
+        let mut attributes = crossterm::style::Attributes::default();
+        if self.bold {
+            attributes.set(crossterm::style::Attribute::Bold);
+        }
+        if self.dimmed {
+            attributes.set(crossterm::style::Attribute::Dim);
+        }
+        if self.italic {
+            attributes.set(crossterm::style::Attribute::Italic);
+        }
+        if self.underline {
+            attributes.set(crossterm::style::Attribute::Underlined);
+        }
+        if self.slow_blink {
+            attributes.set(crossterm::style::Attribute::SlowBlink);
+        }
+        if self.rapid_blink {
+            attributes.set(crossterm::style::Attribute::RapidBlink);
+        }
+        if self.reverse {
+            attributes.set(crossterm::style::Attribute::Reverse);
+        }
+        if self.hidden {
+            attributes.set(crossterm::style::Attribute::Hidden);
+        }
+        if self.strikethrough {
+            attributes.set(crossterm::style::Attribute::CrossedOut);
+        }
+        attributes
+    }
 }
 
 /// A foreground color, background color and font-style.
@@ -261,6 +319,16 @@ impl Style {
 
         ansi_style
     }
+
+    /// Convert to a `crossterm::style::ContentStyle` (if the `crossterm` feature is enabled).
+    #[cfg(feature = "crossterm")]
+    pub fn to_crossterm_style(&self) -> crossterm::style::ContentStyle {
+        crossterm::style::ContentStyle {
+            foreground_color: self.foreground.as_ref().map(Color::to_crossterm_color),
+            background_color: self.background.as_ref().map(Color::to_crossterm_color),
+            attributes: self.font_style.to_crossterm_attributes(),
+        }
+    }
 }
 
 #[cfg(test)]
